@@ -209,15 +209,15 @@ test_that("set_speed adequately raises warnings and errors", {
 })
 
 
-# filename_from_metadata --------------------------------------------------
+# fileurl_from_metadata --------------------------------------------------
 
 
 test_that("raises error if version is not a string", {
-  expect_error(filename_from_metadata(version = 6))
+  expect_error(fileurl_from_metadata(version = 6))
 })
 
 test_that("returns expected result", {
-  expect_equal("r5r_v4.9.0_20201112.jar", filename_from_metadata("4.9.0"))
+  expect_equal("https://github.com/ipeaGIT/r5/releases/download/v6.4/r5-v6.4-all.jar", fileurl_from_metadata("6.4.0"))
 })
 
 
